Mr. Men & Little Miss Gifts & Stationery | Book People
Description: Beautiful Mr. Men and Little Miss gifts that perfectly complement Roger Hargreaves' classic children's books are available from Book People.

Gifts & Stationery

# Mr. Men & Little Miss

- Books In stock isbn 5021854020926
  CT0541 Toddlers
  Little Miss Chatterbox: Record & Play (Other)
  Toddlers
  - isbn 5021854020926
  - Books
  - £14.99
  - RRP £24.99
  - Save £10.00
  One of the most popular Little Miss characters, Little Miss Chatterbox is always talking - and now your child can listen to her speak in their own voice!
  A beautiful cuddly toy, all a child has to do is press one hand to record their voice and press the other to hear it played back to them. They can record their voice as many times as they want, too.
  Dimensions: 260 x 210mm
  Book info
  - £14.99
  - RRP £24.99
  - Save £10.00
  Book info
- Books In stock isbn 5021854020940
  CT0542 Toddlers
  Mr Tickle: Tickle Me (Other)
  Toddlers
  - isbn 5021854020940
  - Books
  - £14.99
  - RRP £24.99
  - Save £10.00
  Squeeze Mr. Tickle's tummy and watch him wave his hands about - but make sure he doesn't tickle you!
  Standing 12 inches tall, this interactive cuddly toy is bright, bold and so much fun. Great for Mr. Men fans!
  Suitable for children aged 10 months and older.
  Dimensions: 260 x 210mm
  Book info
  - £14.99
  - RRP £24.99
  - Save £10.00
  Book info
- Books In stock isbn 5021854020957
  CT0543 Toddlers
  Mr Bump: Bump 'n' Crash (Other)
  Toddlers
  - isbn 5021854020957
  - Books
  - £14.99
  - RRP £24.99
  - Save £10.00
  We all know Mr. Bump is clumsy and crashes into things all the time - and now your children can make friends with him as a cuddly toy.
  But this isn't any ordinary cuddly toy - when he has a bump, he makes plenty of noise. Crash! Bang! Wallop! A real treat for little fans of the Mr. Men.
  Dimensions: 240 x 185mm
  Book info
  - £14.99
  - RRP £24.99
  - Save £10.00
  Book info

Terms and Conditions
Close